Keen | Pagination Options Examples
Description: Pagination options datatables examples

# Customer Relationship Management

New Order

### Pagination Options Examples

Reports
The default page control presented by DataTables (forward and backward buttons with up to 7 page numbers in-between) is fine for most situations.

### Extended Pagination

Record ID | Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Ship Date | Status | Type | Actions
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
1 | 61715-075 | China | Tieba | 746 Pine View Junction | Nixie Sailor | Gleichner, Ziemann and Gutkowski | 2/12/2018 | 3 | 2 |
2 | 63629-4697 | Indonesia | Cihaur | 01652 Fulton Trail | Emelita Giraldez | Rosenbaum-Reichel | 8/6/2017 | 6 | 3 |
3 | 68084-123 | Argentina | Puerto Iguazú | 2 Pine View Park | Ula Luckin | Kulas, Cassin and Batz | 5/26/2016 | 1 | 2 |
4 | 67457-428 | Indonesia | Talok | 3050 Buell Terrace | Evangeline Cure | Pfannerstill-Treutel | 7/2/2016 | 1 | 3 |
5 | 31722-529 | Austria | Sankt Andrä-Höch | 3038 Trailsway Junction | Tierney St. Louis | Dicki-Kling | 5/20/2017 | 2 | 3 |
6 | 64117-168 | China | Rongkou | 023 South Way | Gerhard Reinhard | Gleason, Kub and Marquardt | 11/26/2016 | 5 | 3 |
7 | 43857-0331 | China | Baiguo | 56482 Fairfield Terrace | Englebert Shelley | Jenkins Inc | 6/28/2016 | 2 | 3 |
8 | 64980-196 | Croatia | Vinica | 0 Elka Street | Hazlett Kite | Streich LLC | 8/5/2016 | 6 | 1 |
9 | 0404-0360 | Colombia | San Carlos | 38099 Ilene Hill | Freida Morby | Haley, Schamberger and Durgan | 3/31/2017 | 2 | 1 |
10 | 52125-267 | Thailand | Maha Sarakham | 8696 Barby Pass | Obed Helian | Labadie, Predovic and Hammes | 1/26/2017 | 1 | 3 |
11 | 54092-515 | Brazil | Canguaretama | 32461 Ridgeway Alley | Sibyl Amy | Treutel-Ratke | 3/8/2017 | 4 | 2 |
12 | 0185-0130 | China | Jiamachi | 23 Walton Pass | Norri Foldes | Strosin, Nitzsche and Wisozk | 4/2/2017 | 3 | 1 |
13 | 21130-678 | China | Qiaole | 328 Glendale Hill | Myrna Orhtmann | Miller-Schiller | 6/7/2016 | 3 | 1 |
14 | 40076-953 | Portugal | Burgau | 52550 Crownhardt Court | Sioux Kneath | Rice, Cole and Spinka | 10/11/2017 | 4 | 1 |
15 | 36987-3005 | Portugal | Bacelo | 548 Morrow Terrace | Christa Jacmar | Brakus-Hansen | 8/17/2017 | 1 | 2 |
16 | 67510-0062 | South Africa | Pongola | 02534 Hauk Trail | Shandee Goracci | Bergnaum, Thiel and Schuppe | 7/24/2016 | 5 | 3 |
17 | 36987-2542 | Russia | Novokizhinginsk | 19427 Sloan Road | Jerrome Colvie | Kreiger, Glover and Connelly | 3/4/2016 | 3 | 1 |
18 | 11673-479 | Brazil | Conceição das Alagoas | 191 Stone Corner Road | Michaelina Plenderleith | Legros-Gleichner | 2/21/2018 | 1 | 2 |
19 | 47781-264 | Ukraine | Yasinya | 1481 Sauthoff Place | Lombard Luthwood | Haag LLC | 1/21/2016 | 1 | 2 |
20 | 42291-712 | Indonesia | Kembang | 9029 Blackbird Point | Leonora Chevin | Mann LLC | 9/6/2017 | 2 | 3 |
21 | 64679-154 | Mongolia | Sharga | 102 Holmberg Park | Tannie Seakes | Blanda Group | 7/31/2016 | 6 | 3 |
22 | 49348-055 | China | Guxi | 45 Butterfield Street | Yardley Wetherell | Gerlach-Schultz | 4/3/2017 | 2 | 2 |
23 | 47593-438 | Portugal | Viso | 97 Larry Center | Bryn Peascod | Larkin and Sons | 5/22/2016 | 6 | 1 |
24 | 54569-0175 | Japan | Minato | 077 Hoffman Center | Chrissie Jeromson | Brakus-McCullough | 11/26/2017 | 2 | 1 |
25 | 0093-1016 | Indonesia | Merdeka | 3150 Cherokee Center | Gusti Clamp | Stokes Group | 4/12/2018 | 6 | 2 |
26 | 0093-5142 | China | Jianggao | 289 Badeau Alley | Otis Jobbins | Ruecker, Leffler and Abshire | 3/6/2018 | 4 | 2 |
27 | 51523-026 | Germany | Erfurt | 132 Chive Way | Lonnie Haycox | Feest Group | 4/24/2018 | 1 | 3 |
28 | 49035-522 | Australia | Eastern Suburbs Mc | 074 Algoma Drive | Heddi Castelli | Kessler and Sons | 1/12/2017 | 5 | 1 |
29 | 58411-198 | Ethiopia | Kombolcha | 91066 Amoth Court | Tuck O'Dowgaine | Simonis, Rowe and Davis | 5/6/2017 | 1 | 1 |
30 | 27495-006 | Portugal | Arrifes | 3 Fairfield Junction | Vernon Cosham | Kreiger-Nicolas | 2/8/2017 | 4 | 2 |
31 | 55154-8284 | Philippines | Talisay | 09 Sachtjen Junction | Bryna MacCracken | Hyatt-Witting | 7/22/2017 | 2 | 1 |
32 | 62678-207 | Libya | Zuwārah | 82 Thackeray Pass | Freda Arnall | Dicki, Morar and Stiedemann | 7/22/2016 | 3 | 3 |
33 | 68428-725 | China | Zhangcun | 3 Goodland Terrace | Pavel Kringe | Goldner-Lehner | 4/2/2017 | 4 | 1 |
34 | 0363-0724 | Morocco | Temara | 9550 Weeping Birch Crossing | Felix Nazaret | Waters, Quigley and Keeling | 6/4/2016 | 5 | 3 |
35 | 37000-102 | Paraguay | Los Cedrales | 1 Ridge Oak Way | Penrod Allanby | Rodriguez Group | 3/5/2018 | 2 | 3 |
36 | 55289-002 | Philippines | Dologon | 9 Vidon Terrace | Hubey Passby | Lemke-Hermiston | 6/29/2017 | 2 | 3 |
37 | 15127-874 | Tanzania | Nanganga | 33 Anniversary Parkway | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | 2/18/2018 | 3 | 1 |
38 | 49349-123 | Indonesia | Pule | 77292 Bonner Plaza | Alfonse Lawrance | Schuppe-Harber | 4/14/2017 | 1 | 3 |
39 | 17089-415 | Palestinian Territory | Za‘tarah | 42806 Ridgeview Terrace | Kessiah Chettoe | Mraz LLC | 3/4/2017 | 5 | 2 |
40 | 51327-510 | Philippines | Esperanza | 4 Linden Court | Natka Fairbanks | Mueller-Greenholt | 6/21/2017 | 3 | 3 |

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!